/*
    Large Time Screensaver
    Copyright 2005 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Martin Storsj
    martin@martin.st
*/

#include "LargeTime.h"
#include <e32base.h>
#include <aknkeylock.h>
#include <settinginfo.h>
#include <flogger.h>
#include <hal.h>
#include <e32math.h>

_LIT(KScreensaverName, "Large Time");
const TInt KSegmentThickness = 3;
const TInt KSegmentMargin = 1;
const TInt KNumberMargin = 5;
const TInt KNumbersWidth = 150;
const TInt KNumbersHeight = 60;
const TInt KScreenWidth = 176;
const TInt KScreenHeight = 208;
const TInt KEnvelopeWidth = 75;
const TInt KCallsWidth = 60;
const TInt KEnvelopeCallsHeight = 55;
const TInt KIdentifierMarginX = 20;
const TInt KMarginY = 15;
const TInt KScreenMarginY = 5;

//#define LOG(x) RFileLogger::WriteFormat(_L("debug"), _L("log.txt"), EFileLoggingModeAppend, x)
#define LOG(x)

GLDEF_C TInt E32Dll(TDllReason aReason) {
	return KErrNone;
}

EXPORT_C MScreensaverPlugin* CreatePluginModule() {
	return new CLargeTime();
}

CLargeTime::CLargeTime() {
}

CLargeTime::~CLargeTime() {
}

TInt CLargeTime::InitializeL(MScreensaverPluginHost* aHost) {
	LOG(_L("InitializeL\n"));
	iHost = aHost;

	iHost->OverrideStandardIndicators();
	iHost->SetRefreshTimerValue(20*1000000);

	iEikEnv = CEikonEnv::Static();

	iSeed = User::TickCount();

	iLastTotHeight = 0;

	iPeriod = 1000/64;
	TInt period;
	if (HAL::Get(HALData::ESystemTickPeriod, period) == KErrNone)
		iPeriod = period / 1000;
	iLastRandomize = User::TickCount() - 60*1000/iPeriod;


	LOG(_L("InitializeL done\n"));
	return KErrNone;
}

void CLargeTime::GetState() {
	iMsgs = 0;
	iCalls = 0;
	TIndicatorPayload result;
	TInt status = iHost->GetIndicatorPayload(EScreensaverIndicatorIndexNewMessages, result);
	if (status == KErrNone)
		iMsgs = result.iInteger;

	status = iHost->GetIndicatorPayload(EScreensaverIndicatorIndexNewMissedCalls, result);
	if (status == KErrNone)
		iCalls = result.iInteger;

	TInt profile, ringing;
	TRAPD(err,
		CSettingInfo* info = CSettingInfo::NewL(NULL);
		CleanupStack::PushL(info);
		User::LeaveIfError(info->Get(SettingInfo::EActiveProfile, profile));
		User::LeaveIfError(info->Get(SettingInfo::ERingingType, ringing));
		CleanupStack::PopAndDestroy();
		);

	iSilent = EFalse;
	if (err == KErrNone)
		iSilent = ringing == 4;

	iProfile.SetLength(0);
	if (profile != 0 && err == KErrNone) {
		status = iHost->GetIndicatorPayload(EScreensaverIndicatorIndexProfileName, result);
		if (status == KErrNone)
			iProfile = result.iText;
	}

	iLocked = EFalse;
//	status = iHost->GetIndicatorPayload(EScreensaverIndicatorIndexKeyGuardState, result);
//	if (status == KErrNone && result.iInteger != 0)
//		iLocked = ETrue;

	RAknKeyLock keyLock;
	if (keyLock.Connect() == KErrNone) {
		iLocked = keyLock.IsKeyLockEnabled();
		keyLock.Close();
	}

	TTime time;
	time.HomeTime();
	iTime = time.DateTime();
}

TInt CLargeTime::Draw(CWindowGc& aGc) {
	LOG(_L("Draw\n"));
	GetState();


	TInt totHeight = KNumbersHeight;
	if (iMsgs || iCalls)
		totHeight += KMarginY + KEnvelopeCallsHeight;

	const CFont* font = iEikEnv->AnnotationFont();
	TInt bannerHeight = 0;
	if (iLocked || iProfile.Length() > 0) {
		bannerHeight = font->HeightInPixels() + 4;
		totHeight += KMarginY + bannerHeight;
	}




	if (iLastTotHeight != totHeight || (User::TickCount() - iLastRandomize) >= 60*1000/iPeriod) {
		iBannerFirst = Math::Rand(iSeed) % 2;
		iClockFirst = Math::Rand(iSeed) % 2;
		iMsgsFirst = Math::Rand(iSeed) % 2;
		iOffsetY = KScreenMarginY + Math::Rand(iSeed) % (KScreenHeight - totHeight - 2*KScreenMarginY);
		iLastTotHeight = totHeight;
		iLastRandomize = User::TickCount();
	}



	aGc.SetBrushColor(KRgbWhite);
	aGc.Clear(TRect(0, 0, KScreenWidth, KScreenHeight));

	TScreensaverPartialMode partialMode;
	partialMode.iBpp = 0;
	partialMode.iType = EPartialModeTypeMostPowerSaving;
	// padding due to pen size > 1
	iHost->SetActiveDisplayArea(iOffsetY-3, iOffsetY + totHeight+3, partialMode);


	TPoint tl = TPoint(0, iOffsetY);
	if (iBannerFirst && bannerHeight > 0) {
		DrawBanner(aGc, tl, bannerHeight, font);
		tl += TPoint(0, KMarginY);
	}

	if (iClockFirst) {
		DrawClock(aGc, tl);
		tl += TPoint(0, KMarginY);
	}

	if (iMsgs || iCalls) {
		DrawMsgsCalls(aGc, tl);
		tl += TPoint(0, KMarginY);
	}

	if (!iClockFirst) {
		DrawClock(aGc, tl);
		tl += TPoint(0, KMarginY);
	}

	if (!iBannerFirst && bannerHeight > 0) {
		DrawBanner(aGc, tl, bannerHeight, font);
		tl += TPoint(0, KMarginY);
	}

	LOG(_L("Draw done\n"));
	return KErrNone;
}

void CLargeTime::DrawClock(CWindowGc& aGc, TPoint& aPoint) {
	TInt hours = iTime.Hour();
	TInt minutes = iTime.Minute();

	TInt colonWidth = 2*KSegmentThickness;
	TInt firstNumberWidth = 0;
	TSize numberSize = TSize((KNumbersWidth - 4*KNumberMargin - colonWidth)/4, KNumbersHeight);
	TInt realWidth = KNumbersWidth;
	TInt firstOffset = 0;

/*	if (hours < 10) {
		realWidth = numberSize.iWidth*3 + colonWidth + KNumberMargin*3;
	} else if (hours < 20) {
		TInt firstNumberWidth = 2*KSegmentThickness;
		realWidth = numberSize.iWidth*3 + colonWidth + firstNumberWidth + KNumberMargin*4;
		firstOffset = numberSize.iWidth - firstNumberWidth;
	} else {
		realWidth = numberSize.iWidth*4 + colonWidth + KNumberMargin*4;
//		realWidth = KNumbersWidth;
	}
*/
	TPoint tl = TPoint((KScreenWidth-realWidth)/2, aPoint.iY);

//	if (hours >= 10) {
		tl.iX -= firstOffset;
		DrawNumber2(aGc, TRect(tl, numberSize), hours/10);
		tl += TPoint(numberSize.iWidth + KNumberMargin, 0);
//	}
	DrawNumber2(aGc, TRect(tl, numberSize), hours%10);
	tl += TPoint(numberSize.iWidth + KNumberMargin, 0);
	DrawColon(aGc, TRect(tl, TSize(colonWidth, KNumbersHeight)));
	tl += TPoint(colonWidth + KNumberMargin, 0);
	DrawNumber2(aGc, TRect(tl, numberSize), minutes/10);
	tl += TPoint(numberSize.iWidth + KNumberMargin, 0);
	DrawNumber2(aGc, TRect(tl, numberSize), minutes%10);

	aPoint += TPoint(0, KNumbersHeight);
}

void CLargeTime::DrawMsgsCalls(CWindowGc& aGc, TPoint& aPoint) {

	if (iCalls && iMsgs)
		aPoint.iX = (KScreenWidth - KIdentifierMarginX - KEnvelopeWidth - KCallsWidth)/2;
	else if (iCalls)
		aPoint.iX = (KScreenWidth - KCallsWidth)/2;
	else if (iMsgs)
		aPoint.iX = (KScreenWidth - KEnvelopeWidth)/2;

	if (iMsgs && iMsgsFirst) {
		DrawEnvelope(aGc, TRect(aPoint, TSize(KEnvelopeWidth, KEnvelopeCallsHeight)));
		aPoint += TPoint(KEnvelopeWidth + KIdentifierMarginX, 0);
	}
	if (iCalls) {
		DrawCalls(aGc, TRect(aPoint, TSize(KCallsWidth, KEnvelopeCallsHeight)));
		aPoint += TPoint(KCallsWidth + KIdentifierMarginX, 0);
	}
	if (iMsgs && !iMsgsFirst) {
		DrawEnvelope(aGc, TRect(aPoint, TSize(KEnvelopeWidth, KEnvelopeCallsHeight)));
		aPoint += TPoint(KEnvelopeWidth + KIdentifierMarginX, 0);
	}

//	DrawCalls(aGc, TRect(50, 50, 150, 150));
	aPoint += TPoint(0, KEnvelopeCallsHeight);

}

void CLargeTime::DrawBanner(CWindowGc& aGc, TPoint& aPoint, TInt aHeight, const CFont* aFont) {
	TPoint origPoint = aPoint;
	aPoint.iX = 0;

	aGc.SetBrushColor(KRgbGray);
	aGc.Clear(TRect(aPoint, TSize(KScreenWidth, aHeight)));

	aPoint += TPoint(2, 2);
	if (iLocked) {
		DrawKey(aGc, aPoint);
		aPoint += TPoint(23, 0);
	}
	if (iProfile.Length() > 0) {
		aGc.SetPenColor(KRgbBlack);
		aGc.UseFont(aFont);
		aGc.DrawText(iProfile, TPoint(aPoint.iX, aPoint.iY - 2 + aFont->HeightInPixels()));
	}

	aPoint = origPoint + TPoint(0, aHeight);
}

const TDesC16& CLargeTime::Name() const {
	LOG(_L("Name\n"));
	return KScreensaverName;
}

TInt CLargeTime::HandleScreensaverEventL(TScreensaverEvent aEvent, TAny* aData) {
	LOG(_L("HandleScreensaverEventL\n"));
	return KErrNone;
}

TInt CLargeTime::Capabilities() {
	LOG(_L("Capabilities\n"));
	return EScpCapsNone;
}

TInt CLargeTime::PluginFunction(TScPluginCaps aFunction, TAny* aParam) {
	LOG(_L("PluginFunction\n"));
	return KErrNone;
}


TInt CLargeTime::DecodeNumber(TInt aNumber) {
	switch (aNumber) {
	case 0:
		return EPartTop | EPartTopLeft | EPartTopRight | EPartBottomLeft | EPartBottomRight | EPartBottom;
	case 1:
		return EPartTopRight | EPartBottomRight;
	case 2:
		return EPartTop | EPartTopRight | EPartCenter | EPartBottomLeft | EPartBottom;
	case 3:
		return EPartTop | EPartCenter | EPartBottom | EPartTopRight | EPartBottomRight;
	case 4:
		return EPartTopLeft | EPartCenter | EPartTopRight | EPartBottomRight;
	case 5:
		return EPartTop | EPartTopLeft | EPartCenter | EPartBottomRight | EPartBottom;
	case 6:
		return EPartTop | EPartTopLeft | EPartBottomLeft | EPartBottom | EPartBottomRight | EPartCenter;
	case 7:
		return EPartTop | EPartTopRight | EPartBottomRight;
	case 8:
		return EPartTop | EPartTopLeft | EPartTopRight | EPartCenter | EPartBottomLeft | EPartBottomRight | EPartBottom;
	case 9:
		return EPartCenter | EPartTopLeft | EPartTop | EPartTopRight | EPartBottomRight | EPartBottom;
	default:
		break;
	}
	return 0;
}

void CLargeTime::DrawNumber(CWindowGc& aGc, TRect aRect, TInt aNumber) {
	TInt parts = DecodeNumber(aNumber);

	TPoint tl = aRect.iTl;
	TPoint br = aRect.iBr - TPoint(1,1);
	TPoint bl = TPoint(tl.iX, br.iY);
	TPoint tr = TPoint(br.iX, tl.iY);
	TPoint cl = TPoint(tl.iX, (tl.iY+br.iY)/2);
	TPoint cr = TPoint(br.iX, (tl.iY+br.iY)/2);

	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ESolidBrush);

	if (parts & EPartTop) {
		TPoint points[4];
		points[0] = tl + TPoint(KSegmentMargin, 0);
		points[1] = tr + TPoint(-KSegmentMargin, 0);
		points[2] = tr + TPoint(-KSegmentMargin - KSegmentThickness, KSegmentThickness);
		points[3] = tl + TPoint(KSegmentMargin + KSegmentThickness, KSegmentThickness);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartBottom) {
		TPoint points[4];
		points[0] = bl + TPoint(KSegmentMargin, 0);
		points[1] = bl + TPoint(KSegmentMargin + KSegmentThickness, -KSegmentThickness);
		points[2] = br + TPoint(-KSegmentMargin - KSegmentThickness, -KSegmentThickness);
		points[3] = br + TPoint(-KSegmentMargin, 0);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartTopLeft) {
		TPoint points[4];
		points[0] = tl + TPoint(0, KSegmentMargin);
		points[1] = tl + TPoint(KSegmentThickness, KSegmentMargin + KSegmentThickness);
		points[2] = cl + TPoint(KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[3] = cl + TPoint(0, -KSegmentMargin);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartTopRight) {
		TPoint points[4];
		points[0] = tr + TPoint(0, KSegmentMargin);
		points[1] = cr + TPoint(0, -KSegmentMargin);
		points[2] = cr + TPoint(-KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[3] = tr + TPoint(-KSegmentThickness, KSegmentMargin + KSegmentThickness);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartBottomLeft) {
		TPoint points[4];
		points[0] = cl + TPoint(0, KSegmentMargin);
		points[1] = cl + TPoint(KSegmentThickness, KSegmentMargin + KSegmentThickness);
		points[2] = bl + TPoint(KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[3] = bl + TPoint(0, -KSegmentMargin);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartBottomRight) {
		TPoint points[4];
		points[0] = cr + TPoint(0, KSegmentMargin);
		points[1] = br + TPoint(0, -KSegmentMargin);
		points[2] = br + TPoint(-KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[3] = cr + TPoint(-KSegmentThickness, KSegmentMargin + KSegmentThickness);
		aGc.DrawPolygon(points, 4);
	}
	if (parts & EPartCenter) {
		TPoint points[6];
		points[0] = cl + TPoint(KSegmentMargin, 0);
		points[1] = cl + TPoint(KSegmentMargin + KSegmentThickness/2, -KSegmentThickness/2);
		points[2] = cr + TPoint(-KSegmentMargin - KSegmentThickness/2, -KSegmentThickness/2);
		points[3] = cr + TPoint(-KSegmentMargin, 0);
		points[4] = cr + TPoint(-KSegmentMargin - KSegmentThickness/2, KSegmentThickness/2);
		points[5] = cl + TPoint(KSegmentMargin + KSegmentThickness/2, KSegmentThickness/2);
		aGc.DrawPolygon(points, 6);
	}

}

void CLargeTime::DrawNumber2(CWindowGc& aGc, TRect aRect, TInt aNumber) {
	TInt parts = DecodeNumber(aNumber);

	TPoint tl = aRect.iTl;
	TPoint br = aRect.iBr - TPoint(1,1);
	TPoint bl = TPoint(tl.iX, br.iY);
	TPoint tr = TPoint(br.iX, tl.iY);
	TPoint cl = TPoint(tl.iX, (tl.iY+br.iY)/2);
	TPoint cr = TPoint(br.iX, (tl.iY+br.iY)/2);

	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ESolidBrush);

	if (parts & EPartTop) {
		TPoint points[6];
		points[0] = tl + TPoint(KSegmentMargin + KSegmentThickness, KSegmentThickness);
		points[1] = tl + TPoint(KSegmentMargin + 2*KSegmentThickness, 0);
		points[2] = tr + TPoint(-KSegmentMargin - 2*KSegmentThickness, 0);
		points[3] = tr + TPoint(-KSegmentMargin - KSegmentThickness, KSegmentThickness);
		points[4] = tr + TPoint(-KSegmentMargin - 2*KSegmentThickness, 2*KSegmentThickness);
		points[5] = tl + TPoint(KSegmentMargin + 2*KSegmentThickness, 2*KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartBottom) {
		TPoint points[6];
		points[0] = bl + TPoint(KSegmentMargin + KSegmentThickness, -KSegmentThickness);
		points[1] = bl + TPoint(KSegmentMargin + 2*KSegmentThickness, -2*KSegmentThickness);
		points[2] = br + TPoint(-KSegmentMargin - 2*KSegmentThickness, -2*KSegmentThickness);
		points[3] = br + TPoint(-KSegmentMargin - KSegmentThickness, -KSegmentThickness);
		points[4] = br + TPoint(-KSegmentMargin - 2*KSegmentThickness, 0);
		points[5] = bl + TPoint(KSegmentMargin + 2*KSegmentThickness, 0);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartTopLeft) {
		TPoint points[6];
		points[0] = tl + TPoint(KSegmentThickness, KSegmentMargin + KSegmentThickness);
		points[1] = tl + TPoint(2*KSegmentThickness, KSegmentMargin + 2*KSegmentThickness);
		points[2] = cl + TPoint(2*KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[3] = cl + TPoint(KSegmentThickness, -KSegmentMargin);
		points[4] = cl + TPoint(0, -KSegmentMargin - KSegmentThickness);
		points[5] = tl + TPoint(0, KSegmentMargin + 2*KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartTopRight) {
		TPoint points[6];
		points[0] = tr + TPoint(-KSegmentThickness, KSegmentMargin + KSegmentThickness);
		points[1] = tr + TPoint(0, KSegmentMargin + 2*KSegmentThickness);
		points[2] = cr + TPoint(0, -KSegmentMargin - KSegmentThickness);
		points[3] = cr + TPoint(-KSegmentThickness, -KSegmentMargin);
		points[4] = cr + TPoint(-2*KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[5] = tr + TPoint(-2*KSegmentThickness, KSegmentMargin + 2*KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartBottomLeft) {
		TPoint points[6];
		points[0] = cl + TPoint(KSegmentThickness, KSegmentMargin);
		points[1] = cl + TPoint(2*KSegmentThickness, KSegmentMargin + KSegmentThickness);
		points[2] = bl + TPoint(2*KSegmentThickness, -KSegmentMargin - 2*KSegmentThickness);
		points[3] = bl + TPoint(KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[4] = bl + TPoint(0, -KSegmentMargin - 2*KSegmentThickness);
		points[5] = cl + TPoint(0, KSegmentMargin + KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartBottomRight) {
		TPoint points[6];
		points[0] = cr + TPoint(-KSegmentThickness, KSegmentMargin);
		points[1] = cr + TPoint(0, KSegmentMargin + KSegmentThickness);
		points[2] = br + TPoint(0, -KSegmentMargin - 2*KSegmentThickness);
		points[3] = br + TPoint(-KSegmentThickness, -KSegmentMargin - KSegmentThickness);
		points[4] = br + TPoint(-2*KSegmentThickness, -KSegmentMargin - 2*KSegmentThickness);
		points[5] = cr + TPoint(-2*KSegmentThickness, KSegmentMargin + KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}
	if (parts & EPartCenter) {
		TPoint points[6];
		points[0] = cl + TPoint(KSegmentMargin + KSegmentThickness, 0);
		points[1] = cl + TPoint(KSegmentMargin + 2*KSegmentThickness, -KSegmentThickness);
		points[2] = cr + TPoint(-KSegmentMargin - 2*KSegmentThickness, -KSegmentThickness);
		points[3] = cr + TPoint(-KSegmentMargin - KSegmentThickness, 0);
		points[4] = cr + TPoint(-KSegmentMargin - 2*KSegmentThickness, KSegmentThickness);
		points[5] = cl + TPoint(KSegmentMargin + 2*KSegmentThickness, KSegmentThickness);
		aGc.DrawPolygon(points, 6);
	}

}


void CLargeTime::DrawColon(CWindowGc& aGc, TRect aRect) {
	TPoint top = TPoint((aRect.iTl.iX+aRect.iBr.iX)/2, aRect.iTl.iY + aRect.Size().iHeight/4);
	TPoint bottom = TPoint((aRect.iTl.iX+aRect.iBr.iX)/2, aRect.iTl.iY + aRect.Size().iHeight*3/4);
	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ESolidBrush);

	aGc.DrawRect(TRect(top - TPoint(KSegmentThickness, KSegmentThickness), TSize(KSegmentThickness*2, KSegmentThickness*2)));
	aGc.DrawRect(TRect(bottom - TPoint(KSegmentThickness, KSegmentThickness), TSize(KSegmentThickness*2, KSegmentThickness*2)));
}

void CLargeTime::DrawKey(CWindowGc& aGc, TPoint aPoint) {
	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ENullBrush);
	aGc.SetPenSize(TSize(2,2));
	aGc.DrawEllipse(TRect(TPoint(aPoint.iX+13, aPoint.iY+0), TSize(6, 8)));
	aGc.DrawLine(TPoint(aPoint.iX+13, aPoint.iY+4), TPoint(aPoint.iX+0, aPoint.iY+4));
	aGc.DrawLine(TPoint(aPoint.iX+2, aPoint.iY+4), TPoint(aPoint.iX+2, aPoint.iY+7));
	aGc.SetPenSize(TSize(1,1));
}

void CLargeTime::DrawEnvelope(CWindowGc& aGc, TRect aRect) {
	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ENullBrush);
	aGc.SetPenSize(TSize(5,5));
	aGc.DrawRect(aRect);
	TPoint points[3];
	points[0] = aRect.iTl;
	points[1] = TPoint((aRect.iTl.iX + aRect.iBr.iX)/2, (aRect.iTl.iY + aRect.iBr.iY)/2);
	points[2] = TPoint(aRect.iBr.iX-1, aRect.iTl.iY);
	aGc.DrawPolyLine(points, 3);
	aGc.SetPenSize(TSize(1,1));
}

void CLargeTime::DrawCalls(CWindowGc& aGc, TRect aRect) {
//	aGc.SetBrushColor(KRgbGreen);
//	aGc.Clear(aRect);
	aGc.SetPenColor(KRgbBlack);
	aGc.SetBrushStyle(CGraphicsContext::ESolidBrush);

	TPoint tl = aRect.iTl;
	TSize size = aRect.Size();
#define POINT(x,y) TPoint(tl.iX+size.iWidth*x/80, tl.iY+size.iHeight*y/80)
#define ADDPOINT() do { points[i++] = POINT(curPos.iX, curPos.iY); } while (0)
#define MOVE(x,y) do { curPos += TPoint(x,y); ADDPOINT(); } while (0)
	TInt i, x, y;
	TPoint points[15], curPos;

	i = 0;
	curPos = TPoint(45, 0);
	ADDPOINT();
	MOVE(15, 0);
	MOVE(0, 37);
	MOVE(-10, 10);
	MOVE(-30, 0);
	MOVE(-10, -10);
	MOVE(0, -20);
	MOVE(-10, 0);
	MOVE(17, -17);
	MOVE(1, 0);
	MOVE(17, 17);
	MOVE(-10, 0);
	MOVE(0, 15);
	MOVE(20, 0);
	aGc.SetPenSize(TSize(1,1));
	aGc.SetBrushColor(KRgbBlack);
	aGc.DrawPolygon(points, i);

	i = 0;
	curPos = TPoint(30, 50);
	ADDPOINT();
	MOVE(25, -25);
	MOVE(20, 0);
	MOVE(5, 5);
	MOVE(0, 10);
	MOVE(-10, 10);
	MOVE(-10, 0);
	MOVE(0, -10);
	MOVE(-20, 20);
	MOVE(10, 0);
	MOVE(0, 10);
	MOVE(-10, 10);
	MOVE(-10, 0);
	MOVE(-5, -5);
	MOVE(0, -20);
	aGc.SetPenSize(TSize(5,5));
	aGc.SetBrushColor(KRgbWhite);
	aGc.DrawPolygon(points, i);

	aGc.SetPenSize(TSize(1,1));
}



